@@ -35,7 +35,7 @@ def main(
         help="Choose a catalog topic.",
     ),
 ):
-    """![Downloading](https://github.com/JnyJny/springer_downloader/raw/master/demo/download-catalog.gif)
+    """![Downloading](https://github.com/JnyJny/springer_downloader/raw/master/demo/animations/download-catalog.gif)
     __Springer Textbook Bulk Download Tool__
     
     ## NOTICE
